@@ -3,8 +3,9 @@ import io
 from datomizer import DatoMapper
 from datomizer.helpers import common_helper
 from datomizer.helpers.train import enhance_ml_helper, train_helper
-from datomizer.utils import general, step_types
 from datomizer.helpers.wrapper import schema_wrapper
+from datomizer.utils.general import ID, MODELS, ERROR
+from datomizer.utils.step_types import ML_TRAIN_AND_GENERATE
 from datomizer.utils.enhance_ml import Metrics, Algorithms
 
 
@@ -54,12 +55,12 @@ class DatoEnhancer(object):
                                                   business_unit_id=self.dato_mapper.business_unit_id,
                                                   project_id=self.dato_mapper.project_id,
                                                   flow_id=self.dato_mapper.flow_id,
-                                                  step_type=step_types.ML_TRAIN_AND_GENERATE,
+                                                  step_type=ML_TRAIN_AND_GENERATE,
                                                   train_id=self.train_id)
-        if status == general.ERROR:
+        if status == ERROR:
             raise Exception("Trainer Failed")
         train = train_helper.get_train_iteration(self.dato_mapper, self.train_id)
-        self.model_id = train[general.MODELS][0][general.ID]
+        self.model_id = train[MODELS][0][ID]
 
     def get_generated_data(self) -> None:
         self.restore_validation()
