@@ -1,10 +1,12 @@
 from datomizer import Datomizer
-from datomizer.helpers.datasource import datasource_helper
-from datomizer.helpers import common_helper
-from datomizer.helpers.business_unit_project import business_unit_project_helper as bu_proj_helper
-from datomizer.helpers.autodiscovery import autodiscovery_helper
+from datomizer.helpers.datasource.datasource_helper import (create_origin_private_datasource_from_path,
+                                                            create_origin_private_datasource_from_df)
+from datomizer.helpers.common_helper import get_flow, wait_for_step_type
+from datomizer.helpers.business_unit_project.business_unit_project_helper import get_default_business_unit_project
+from datomizer.helpers.autodiscovery.autodiscovery_helper import discover, get_schema_discovery
 from datomizer.helpers.wrapper.schema_wrapper import SchemaWrapper
-from datomizer.utils import step_types, general
+from datomizer.utils.general import ORIGIN_DATASOURCE_ID, ERROR
+from datomizer.utils.step_types import COLUMN_DISCOVERY
 
 
 class DatoMapper(object):
@@ -21,7 +23,7 @@ class DatoMapper(object):
             datomizer: the Datomizer authentication object."""
         datomizer.next_step_validation()
         self.datomizer = datomizer
-        self.business_unit_id, self.project_id = bu_proj_helper.get_default_business_unit_project(self.datomizer)
+        self.business_unit_id, self.project_id = get_default_business_unit_project(self.datomizer)
 
     @classmethod
     def restore(cls, datomizer: Datomizer, flow_id):
@@ -32,15 +34,15 @@ class DatoMapper(object):
 
     def get_flow(self) -> dict:
         self.restore_validation()
-        return common_helper.get_flow(self.datomizer, self.business_unit_id, self.project_id, self.flow_id)
+        return get_flow(self.datomizer, self.business_unit_id, self.project_id, self.flow_id)
 
     def create_datasource_from_path(self, path) -> None:
         self.set_datasource_validation()
-        self.datasource_id = datasource_helper.create_origin_private_datasource_from_path(self.datomizer, path)
+        self.datasource_id = create_origin_private_datasource_from_path(self.datomizer, path)
 
     def create_datasource_from_df(self, df, name="temp_df") -> None:
         self.set_datasource_validation()
-        self.datasource_id = datasource_helper.create_origin_private_datasource_from_df(self.datomizer, df, name)
+        self.datasource_id = create_origin_private_datasource_from_df(self.datomizer, df, name)
 
     def create_datasource(self, path, df, name):
         if path is not None:
@@ -48,7 +50,8 @@ class DatoMapper(object):
         elif df is not None:
             self.create_datasource_from_df(df, name)
 
-    def discover(self, path=None, df=None, df_name=None, sample_percent: int = 1, title: str = "sdk_flow", wait=True) -> None:
+    def discover(self, path=None, df=None, df_name=None, sample_percent: int = 1, title: str = "sdk_flow",
+                 wait=True) -> None:
         """Extract the structure of the input data.
         Args:
             path: full path for the input data
@@ -60,23 +63,23 @@ class DatoMapper(object):
         self.create_datasource(path, df, df_name if df_name else "temp_sdk")
 
         self.pre_run_validation()
-        self.flow_id = autodiscovery_helper.discover(self.datomizer,
-                                                     self.business_unit_id, self.project_id, self.datasource_id,
-                                                     sample_percent, title)
+        self.flow_id = discover(self.datomizer,
+                                self.business_unit_id, self.project_id, self.datasource_id,
+                                sample_percent, title)
         if wait:
             self.wait()
 
     def wait(self) -> None:
         """Wait until the discovery method returns."""
         self.restore_validation()
-        status = common_helper.wait_for_step_type(datomizer=self.datomizer,
-                                                  business_unit_id=self.business_unit_id,
-                                                  project_id=self.project_id,
-                                                  flow_id=self.flow_id,
-                                                  step_type=step_types.COLUMN_DISCOVERY)
-        if status == general.ERROR:
+        status = wait_for_step_type(datomizer=self.datomizer,
+                                    business_unit_id=self.business_unit_id,
+                                    project_id=self.project_id,
+                                    flow_id=self.flow_id,
+                                    step_type=COLUMN_DISCOVERY)
+        if status == ERROR:
             raise Exception("Auto Discovery Failed")
-        self.datasource_id = self.get_flow()[general.ORIGIN_DATASOURCE_ID]
+        self.datasource_id = self.get_flow()[ORIGIN_DATASOURCE_ID]
         self.get_schema_discovery()
 
     def get_schema_discovery(self) -> dict:
@@ -85,11 +88,10 @@ class DatoMapper(object):
             Datomize mapping dictionary"""
         self.restore_validation()
         if self.schema:
-            return
-        self.schema = SchemaWrapper(autodiscovery_helper
-                                    .get_schema_discovery(self.datomizer,
-                                                          self.business_unit_id, self.project_id, self.flow_id))
-        return self.schema.schema
+            return self.schema
+        self.schema = SchemaWrapper(get_schema_discovery(self.datomizer,
+                                                         self.business_unit_id, self.project_id, self.flow_id))
+        return self.schema
 
     def base_validation(self):
         if not (self.business_unit_id > 0 and self.project_id > 0):
