@@ -1,6 +1,6 @@
 from datomizer.helpers.authentication.authentication_helper import *
 from datomizer.utils.general import ACCESS_TOKEN, REFRESH_TOKEN, AUTHORIZATION, BEARER_TOKEN, D_REALM
-
+import atexit
 
 class Datomizer(object):
     domain: str
@@ -22,6 +22,7 @@ class Datomizer(object):
         token_response = post_token(realm=self.realm, domain=self.domain,
                                     username=username, password=password)
         self.config_token(token_response)
+        atexit.register(self.__close)
 
     def refresh_token_headers(self):
         token_response = post_refresh_token(realm=self.realm,
@@ -74,12 +75,7 @@ class Datomizer(object):
             print(response.content)
             raise Exception(not_valid_message)
 
-    def close(self):
+    def __close(self):
         post_log_out(realm=self.realm, domain=self.domain,
                      token=self.access_token, refresh_token=self.refresh_token)
 
-    def __enter__(self):
-        return self
-
-    def __exit__(self, exc_type, exc_value, traceback):
-        self.close()
