@@ -3,7 +3,8 @@ import io
 import requests
 import time
 from datomizer import Datomizer
-from datomizer.utils import constants, step_types, general
+from datomizer.utils import constants, general
+from datomizer.utils.general import TASKS, TASK_STATUS, STEP_TYPE
 
 
 def get_flow(datomizer: Datomizer,
@@ -34,11 +35,11 @@ def get_relevant_steps_status(response_json: {}, step_type: str = '', train_id:
 
 def get_steps_status(steps: [], step_type) -> str:
     for step in steps:
-        for task in step['tasks']:
-            if task['taskStatus'] == general.ERROR:
+        for task in step[TASKS]:
+            if task[TASK_STATUS] == general.ERROR:
                 return general.ERROR
-            if step["stepType"] == step_type:
-                return task['taskStatus']
+            if step[STEP_TYPE] == step_type:
+                return task[TASK_STATUS]
 
     return general.INITIALIZING
 
