@@ -48,6 +48,7 @@ AUTO_SCHEMA_DISCOVERY = "/autoSchemaDiscovery"
 SAMPLE_DATA_CSV = "/sampleTableCSV"
 GENERATED_DATA_CSV = "/generatedTableCSV"
 TRAIN = "/train"
+TRAIN_AND_GENERATE = "/trainAndGenerate"
 ENHANCE_ML = "/enhanceMLFlows"
 ENHANCE_ML_EVALUATE = "/enhancedMLEvaluate"
 ENHANCE_ML_TRAIN_GEN = "/enhancedMLTrainAndGenerate"
@@ -63,7 +64,7 @@ MANAGEMENT_GET_GENERATIVE_FLOW = SINGLE_PROJECT_URL + GENERATIVE_MODEL + "/%s"
 MANAGEMENT_GET_SYNTH_FLOW = SINGLE_PROJECT_URL + SYNTH_FLOW + "/%s"
 MANAGEMENT_POST_ADD_FLOW = SINGLE_PROJECT_URL + GENERATIVE_MODEL
 MANAGEMENT_GET_SCHEMA_DISCOVERY = SINGLE_PROJECT_URL + FLOWS_URL + "/%s" + AUTO_SCHEMA_DISCOVERY
-MANAGEMENT_PUT_TRAIN_FLOW = SINGLE_PROJECT_URL + GENERATIVE_MODEL + "/%s" + TRAIN
+MANAGEMENT_PUT_TRAIN_FLOW = SINGLE_PROJECT_URL + GENERATIVE_MODEL + "/%s" + TRAIN_AND_GENERATE
 MANAGEMENT_PUT_ENHANCE_ML_EVALUATE_FLOW = SINGLE_PROJECT_URL + ENHANCE_ML + "/%s" + ENHANCE_ML_EVALUATE
 MANAGEMENT_PUT_ENHANCE_ML_TRAIN_GEN_FLOW = SINGLE_PROJECT_URL + ENHANCE_ML + "/%s" + ENHANCE_ML_TRAIN_GEN
 MANAGEMENT_GET_GENERATIVE_SAMPLE = SINGLE_PROJECT_URL + GENERATIVE_MODEL + "/%s" + MODEL + "/%s" + SAMPLE_TABLE + "/%s"
